@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 from lib2to3.fixer_base import BaseFix
 from lib2to3.pygram import python_symbols as symbols
 
@@ -5,7 +6,7 @@ from .utils import get_leaves_after_last_newline
 
 
 class FixTrailingBlankLines(BaseFix):
-    u'''
+    '''
     Trailing blank lines are superfluous.
     '''
 
@@ -33,9 +34,9 @@ class FixTrailingBlankLines(BaseFix):
                 if result.prefix.strip():
                     # If there are existing comments, we need to add two
                     # newlines in order to have a trailing newline.
-                    new_prefix = u'%s\n\n' % result.prefix.rstrip()
+                    new_prefix = '%s\n\n' % result.prefix.rstrip()
                 else:
-                    new_prefix = u'%s\n' % result.prefix.rstrip()
+                    new_prefix = '%s\n' % result.prefix.rstrip()
                 if result.prefix != new_prefix:
                     result.prefix = new_prefix
                     result.changed()
